#!/usr/bin/env python
# coding: utf-8
from __future__ import absolute_import, with_statement

import sys
import os
import argparse
import yaml
import jinja2

import junkyardmap


parser = argparse.ArgumentParser(description='Generates a network overview.')

parser.add_argument('source',
                      metavar='SOURCE',
                      type=str,
                      help='The YAML-file from which to read the description.')

parser.add_argument('target',
                   metavar='TARGET',
                   type=str,
                   help='The filename to which the HTML overview is rendered.')

parser.add_argument('--version', action='version', version=junkyardmap.version)

def main():
    args = parser.parse_args()
    with open(args.source, 'rb') as source:
        with open(args.target, 'wb') as target:
            data = yaml.load(source)
            data['css'] = css
            target.write(template.render(data).encode('utf-8'))


template = jinja2.Template(u"""\
<!doctype html>
<html>
    <head>
        <meta http-equiv="Content-Type" content="text/html;charset=utf-8">
        <title>Junk Yard Map</title>
        <style type="text/css">
            {{ css }}
        </style>
    </head>
    <body>
        {% for id, network in networks.items() %}
            <div id="network-{{ id }}"
                 class="network">

                <h1>{{ id }}</h1>

                {% for id, box in network.boxes.items() %}
                    <div class="box"
                         id="box-{{ id }}"
                    >
                        <h2>{{ id }}</h2>

                        <ul class="tags">
                            {% for tag in box.tags %}
                                <li>{{ tag }}</li>
                            {% endfor %}
                        </ul>

                        <ul class="users">
                            {% for user in box.users %}
                                <li><a href=""
                                       data-username="{{ user }}@{{ id }}">{{ user }}</a></li>
                            {% endfor %}
                        </ul>
                    </div>
                {% endfor %}
            </div>
        {% endfor %}

        <div id="ssh">
            $ <input type="text" size="130">
              <button>clear</button>
              <a href="eyJob3BzIjogWyJ4Z3h0cGJrQGVpbnN0ZWluIl19">connect</a>
        </div>

        <script src="http://ajax.googleapis.com/ajax/libs/jquery/1.8.2/jquery.min.js"></script>
        <script type="text/javascript">
            $(document).ready(function() {

                var hops = []

                function update_ssh() {
                    var ssh_command = hops.map(function(username) { return 'ssh -A -t ' + username; }).join(' ');
                    $('#ssh input').attr('value', ssh_command);

                    var data_url = 'data:x-application/hop-description;base64,' + btoa(JSON.stringify({hops: hops}));
                    $('#ssh a').attr('href', data_url)
                }

                $('.box .users a').on('click', function(evt) {
                    evt.preventDefault();
                    hops.push($(this).data('username'));
                    update_ssh();
                });

                $('#ssh button').on('click', function() {
                    hops.pop();
                    update_ssh();
                });

                // clear attribute, to avoid inconsistency
                $('#ssh input').attr('value', '');

            });
        </script>
    </body>
</html>
""")

css = """
body {
    font-family: tahoma,arial,sans-serif;
}

* {
    font: inherit;
    margin: 0;
    padding: 0;
    list-style-type: none;
    text-decoration: none;
    color: inherit;
    border: 0 none transparent;
    background-color: transparent;
}

.network {
    background-color: #ccff99;
    border: 1px solid #99cc66;
    margin: 50px;
    padding: 20px;
}

.network h1 {
    color: #99cc66;
    font-weight: bold;
}

.box {
    vertical-align: top;
    background-color: #eeeeee;
    border: 1px solid #aaaaaa;
    padding: 10px 10px 10px 60px;
    margin: 10px;
    display: inline-block;
    width: 100px;

    background-image: url(network-server.svg);
    background-repeat: no-repeat;
    background-position: 5px 10px;
}

.box h2 {
    font-weight: bold;
    color: #aaaaaa;
}

.box ul.users {
    font-size: 85%;
    margin: 0.5em 0;
}

.box ul.users li a:after {
    content: '@';
    color: #aaaaaa;
}

.box ul.tags {
    margin: 0.5em 0;
}

.box ul.tags li {
    display: inline-block;
    font-size: 65%;
    background-color: #aaaaaa;
    color: #eeeeee;
    padding: 1px 2px;
}

#ssh {
    margin: 50px;
    padding: 20px;
    background-color: black;
    border: 1px solid #333333;
    color: #666666;
    font-weight: bold;
    font-family: consolas,courier,fixed;
}

#ssh input {
    color: #999999;
}
"""

if __name__ == '__main__':
    main()
